@@ -1,5 +1,5 @@
 package App::ManiacDownloader::_BytesDownloaded;
-
+$App::ManiacDownloader::_BytesDownloaded::VERSION = '0.0.13';
 use strict;
 use warnings;
 
@@ -7,19 +7,20 @@ use MooX qw/late/;
 
 use List::Util qw/min/;
 
-has ['_bytes_dled', '_bytes_dled_last_timer'] =>
-    (isa => 'Int', is => 'rw', default => sub { return 0;});
+has [ '_bytes_dled', '_bytes_dled_last_timer' ] =>
+    ( isa => 'Int', is => 'rw', default => sub { return 0; } );
 
-has '_stale_checkpoints_count' => (isa => 'Int', is => 'rw',
-    default => sub { return 0;});
+has '_stale_checkpoints_count' => (
+    isa     => 'Int',
+    is      => 'rw',
+    default => sub { return 0; }
+);
 
 sub _add
 {
-    my ($self, $num_written) = @_;
+    my ( $self, $num_written ) = @_;
 
-    $self->_bytes_dled(
-        $self->_bytes_dled + $num_written,
-    );
+    $self->_bytes_dled( $self->_bytes_dled + $num_written, );
 
     return;
 }
@@ -33,9 +34,9 @@ sub _total_downloaded
 
 sub _were_stale_checkpoints_exceeded
 {
-    my ($self, $MAX_COUNT) = @_;
+    my ( $self, $MAX_COUNT ) = @_;
 
-    return ($self->_stale_checkpoints_count >= $MAX_COUNT);
+    return ( $self->_stale_checkpoints_count >= $MAX_COUNT );
 }
 
 sub _flush_and_report
@@ -44,23 +45,23 @@ sub _flush_and_report
 
     my $difference = $self->_bytes_dled - $self->_bytes_dled_last_timer;
 
-    if ($difference > 0)
+    if ( $difference > 0 )
     {
         $self->_stale_checkpoints_count(0);
     }
     else
     {
-        $self->_stale_checkpoints_count($self->_stale_checkpoints_count + 1);
+        $self->_stale_checkpoints_count( $self->_stale_checkpoints_count + 1 );
     }
 
-    $self->_bytes_dled_last_timer($self->_bytes_dled);
+    $self->_bytes_dled_last_timer( $self->_bytes_dled );
 
-    return ($difference, $self->_bytes_dled);
+    return ( $difference, $self->_bytes_dled );
 }
 
 sub _my_init
 {
-    my ($self, $num_bytes) = @_;
+    my ( $self, $num_bytes ) = @_;
 
     $self->_bytes_dled($num_bytes);
     $self->_bytes_dled_last_timer($num_bytes);
@@ -68,7 +69,6 @@ sub _my_init
     return;
 }
 
-
 1;
 
 __END__
@@ -79,40 +79,12 @@ __END__
 
 =head1 VERSION
 
-version 0.0.12
+version 0.0.13
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2013 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-ManiacDownloader or by email
-to bug-app-maniacdownloader@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc App::ManiacDownloader
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -126,15 +98,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/App-ManiacDownloader>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-ManiacDownloader>
+L<https://metacpan.org/release/App-ManiacDownloader>
 
 =item *
 
@@ -142,31 +106,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-ManiacDownloader>
-
-=item *
-
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-ManiacDownloader>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-ManiacDownloader>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/App-ManiacDownloader>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ManiacDownloader>
 
 =item *
 
@@ -174,13 +114,13 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/App-ManiacDownloader>
+L<http://cpants.cpanauthors.org/dist/App-ManiacDownloader>
 
 =item *
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/A/App-ManiacDownloader>
 
@@ -205,7 +145,7 @@ L<http://deps.cpantesters.org/?module=App::ManiacDownloader>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-app-maniacdownloader at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-ManiacDownloader>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=App-ManiacDownloader>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -214,8 +154,29 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://bitbucket.org/shlomif/perl-App-ManiacDownloader>
+L<https://github.com/shlomif/maniac-downloader>
 
-  hg clone ssh://hg@bitbucket.org/shlomif/perl-App-ManiacDownloader
+  git clone git://github.com/shlomif/maniac-downloader.git
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/maniac-downloader/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =cut
